<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="et">
<context>
    <name>LXQtModuleManager</name>
    <message>
        <location filename="../src/lxqtmodman.cpp" line="323"/>
        <source>Crash Report</source>
        <translation>Veast teatamine</translation>
    </message>
    <message>
        <location filename="../src/lxqtmodman.cpp" line="324"/>
        <source>&lt;b&gt;%1&lt;/b&gt; crashed too many times. Its autorestart has been disabled until next login.</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; on liiga palju kordi kokku jooksnud. Selle teenuse automaatne käivitamine on kuni järgmise sisselogimiseni edasi lükatud.</translation>
    </message>
</context>
<context>
    <name>SessionApplication</name>
    <message>
        <location filename="../src/main.cpp" line="62"/>
        <source>Configuration file path.</source>
        <translation>Seadistuste faili asukoht.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="62"/>
        <location filename="../src/main.cpp" line="63"/>
        <source>file</source>
        <translation>fail</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="63"/>
        <source>Window manager to use.</source>
        <translation>Kasutatav aknahaldur.</translation>
    </message>
    <message>
        <location filename="../src/sessionapplication.cpp" line="83"/>
        <source>DBus Environment</source>
        <translation>DBus keskkkond</translation>
    </message>
    <message>
        <location filename="../src/sessionapplication.cpp" line="84"/>
        <source>The DBus Activation Environment wasn&apos;t updated. Some apps might not work properly</source>
        <translation>DBusi aktiveerimiskeskkonda ei värskendatud. Mõned rakendused ei pruugi korralikult töötada</translation>
    </message>
</context>
<context>
    <name>WmSelectDialog</name>
    <message>
        <location filename="../src/wmselectdialog.ui" line="14"/>
        <source>Welcome to LXQt</source>
        <translation>Tere tulemast kasutama LXQt töölauakeskkonda</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Welcome to LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Please select your default Window Manager.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Tere tulemast kasutama LXQt töölauakeskkonda&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Palun vali vaikimisi kasutatav aknahaldur.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.ui" line="71"/>
        <source>You will be able to change this at any time through Preferences -&gt; Session Settings -&gt; Basic Settings.</source>
        <translation>Sa saad seda hiljem muuta Eelistused -&gt; Sessiooni seadistused -&gt; Põhiseadistused vaatest.</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.cpp" line="65"/>
        <source>Other ...</source>
        <translation>Muu...</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.cpp" line="66"/>
        <source>Choose your favorite one.</source>
        <translation>Vali oma eelistus.</translation>
    </message>
</context>
</TS>
